@@ -5,8 +5,10 @@ from skippy.data.redis import get_files_size, get_storage_nodes, get_dl_bandwidt
 from skippy.data.utils import get_bucket_urn
 
 
+
 def get_best_node(urn: str):
-    node_name = os.environ['NODE_NAME']
+    node_name = os.environ.get('node', None)
+    logging.debug("Node %s" % node_name)
 
     file_size = get_files_size(urn)
 
